import 'reflect-metadata';
import './Services';
import { log, Homebridge } from './Types/types';
import { EventEmitter } from 'events';
import { container } from 'tsyringe';
import { Monitor } from './Services';

class AutomationPlatform {
    private log: log;
    private config: {} = {};
    private api: EventEmitter;

    constructor(log: log, config: {}, api: EventEmitter) {
        this.log = log;
        this.config = config;
        this.api = api;
        this.log('INFO - Registering automation platform');
        this.api.on('didFinishLaunching', this.didFinishLaunching.bind(this));
        this.main();
    }

    /**
     * Called by homebridge to gather accessories.
     * @param callback 
     */
    accessories = (callback: (accessories: Array<unknown>) => void): void => {
        callback([]);
    }

    private main = (): void => {
        //Register the log function for DI
        container.register("log", { useValue: this.log });
        container.resolve(Monitor);
    }

    /**
     * Handler for didFinishLaunching
     * Happens after constructor
     */
    private didFinishLaunching(): void {
        //No external accessories to publish
    }
}

/**
 * Main entry.
 * @param homebridge 
 */
export default function (homebridge: Homebridge): void {
    homebridge.registerPlatform(
        'ml-automation',
        'automation',
        AutomationPlatform,
        true
    );
};